@@ -7,11 +7,12 @@
 # @Software: PyCharm
 from pathlib import Path
 
-
 LOCAL = Path() / 'cqsat'
 HAM_SAT = LOCAL / 'ham_sat.txt'
-TIANGONG = LOCAL / 'tiangong.txt'
+TIANGONG = LOCAL / 'tiangong.json'
 CONFIG = LOCAL / 'config.yml'
 TEMP = LOCAL / 'temp.yaml'
-DATA_DICT = LOCAL / 'data.txt'
+DATA_DICT = LOCAL / 'data.json'
 QTH = LOCAL / 'qth.yml'
+LOG = LOCAL / 'log.log'
+EXERCISE_TEMP = LOCAL / 'exercise_temp.yml'
